//
//  ContentView.swift
//  GraphPad
//
//  Created by Joe Gregg on 10/22/24.
//

import SwiftUI
import SwiftData

struct ContentView: View {
    @Environment(\.modelContext) private var modelContext
    @Query private var graphs: [Graph]
    @State var selected : Graph?
    @State var showInput = false
    @State var graphName = ""
    
    var body: some View {
        NavigationSplitView {
            VStack {
                List {
                    ForEach(graphs) { graph in
                        Text(graph.name)
                            .onTapGesture {
                                selected = graph
                            }
                    }
                }
                Button("Add New Graph") {
                    showInput = true
                }.alert("New Graph", isPresented: $showInput, actions: {
                    TextField("Graph Name", text: $graphName)
                    Button("Create", action: {addItem()})
                    Button("Cancel", role: .cancel, action: {})
                }, message: {
                    Text("Enter a name for the new graph.")
                })
            }
        } detail: {
            if let g = selected {
                GraphDetailView(graph:g)
            } else
            {
                Text("Select an item")
            }
        }
    }

    func addItem() {
        let newGraph = Graph(name:graphName,created:Date())
        modelContext.insert(newGraph)
    }
}
